@@ -481,10 +481,14 @@ self.env.cr.commit()
         _perform_install(module)
     _uninstall_marked_modules()
 
-    if not single_module:
-        # no hard error; could be update of outdated versions, then just
-        # inform the user;
-        DBModules.check_if_all_modules_from_install_are_installed()
+    missing_modules = list(
+        DBModules.check_if_all_modules_from_install_are_installed())
+    if missing_modules and not no_dangling_check:
+        click.secho((
+            f"Not installed: {','.join(missing_modules)}"
+        ), fg='red')
+        sys.exit(-88)
+
 
 
 @odoo_module.command(name="update-i18n", help="Just update translations")
