@@ -827,9 +827,10 @@ def measure_time(method):
         result = method(*args, **kwargs)
         ended = datetime.now()
         duration = (ended - started).total_seconds()
-        click.secho((
-            f"Took: {duration} seconds for {method}"
-        ), fg='yellow')
+        if os.getenv("WODOO_VERBOSE") == "1":
+            click.secho((
+                f"Took: {duration} seconds for {method}"
+            ), fg='yellow')
         return result
     return wrapper
 
